@@ -1,75 +1,6 @@
 OC.L10N.register(
     "spreed",
     {
-    "Participants" : "მონაწილეები",
-    "Chat" : "ჩეთი",
-    "Talk" : "საუბარი",
-    "Copy" : "კოპირება",
-    "Copied!" : "კოპირებულია!",
-    "Not supported!" : "არ არის მხარდაჭერილი!",
-    "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
-    "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
-    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
-    "Password required" : "საჭიროა პაროლი",
-    "Password" : "პაროლი",
-    "Cancel" : "უარყოფა",
-    "Submit" : "გაგზავნა",
-    "Leave call" : "ზარის დატოვება",
-    "Join call" : "შეუერთდით ზარს",
-    "Share link" : "ბმულის გაზიარება",
-    "Copy link" : "ბმულის კოპირება",
-    "Change password" : "პაროლის შეცვლა",
-    "Set password" : "პაროლის დაყენება",
-    "Name" : "სახელი",
-    "Rename" : "სახელის შეცვლა",
-    "Link copied!" : "ბმული დაკოპირდა!",
-    "Conversation with {name}" : "საუბარი მომხმარებელთან {name}",
-    "Error occurred while setting password" : "პაროლის დაყენებისას წარმოიქმნა შეცდომა",
-    "You" : "თქვენ",
-    "Guest" : "სტუმარი",
-    "No messages yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
-    "Send" : "გაგზავნა",
-    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
-    "Today" : "დღეს",
-    "Yesterday" : "გუშინ",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Error occurred while sending message" : "წერილის გაგზავნისას წარმოიშვა შეცდომა",
-    "Edit" : "შეცვლა",
-    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
-    "Waiting for {participantName} to join the call …" : "ზარში შემოსვლისთვის ველოდებით მომხმარებელს {participantName} …",
-    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
-    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
-    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
-    "WebRTC is not supported in your browser :-/" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს :-/",
-    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
-    "Waiting for camera and microphone permissions" : "ველოდებით კამერის და მიკროფონის უფლებებს",
-    "Please, give your browser access to use your camera and microphone in order to use this app." : "ამ აპლიკაციის გამოყენბისთვის გთხოვთ მიანიჭოთ ბრაუზერს წვდომა კამერასა და მიკროფონზე.",
-    "Disable video" : "ვიდეოს გათიშვა",
-    "Share screen" : "ეკრანის გაზიარება",
-    "Show your screen" : "თქვენი ეკრანის ჩვენება",
-    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
-    "No Camera" : "კამერა არაა",
-    "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
-    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
-    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
-    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
-    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
-    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
-    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
-    "moderator" : "მოდერატორი",
-    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
-    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
-    "Remove participant" : "მონაწილის ამოშლა",
-    "Your screen" : "თქვენი ეკრანი",
-    "{participantName}'s screen" : "{participantName} მომხმარებლის ეკრანი",
-    "Guest's screen" : "სტუმრის ეკრანი",
-    "Close" : "დახურვა",
-    "Show screen" : "ეკრანის ჩვენება",
-    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
-    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
-    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
-    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
     "(Duration %s)" : "(ხანგრძლივობა %s)",
     "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
     "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
@@ -79,25 +10,127 @@ OC.L10N.register(
     "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
     "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
     "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
+    "Talk" : "საუბარი",
+    "Guest" : "სტუმარი",
     "Talk to %s" : "საუბარი მომხმარებელთან %s",
+    "Join call" : "შეუერთდით ზარს",
     "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
     "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
+    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
+    "None" : "არც ერთი",
+    "User" : "მომხმარებელი",
+    "Everyone" : "ყველა",
+    "Disabled" : "არაა მოქმედი",
+    "Users" : "მომხმარებლები",
     "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
     "TURN server protocols" : "TURN სერვერის პროტოკოლები",
     "UDP and TCP" : "UDP და TCP",
     "UDP only" : "მხოლოდ UDP",
     "TCP only" : "მხოლოდ TCP",
+    "Copy link" : "ბმულის კოპირება",
+    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
+    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
+    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
+    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
+    "Show your screen" : "თქვენი ეკრანის ჩვენება",
+    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
+    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
+    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
+    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
+    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
+    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
+    "Your screen" : "თქვენი ეკრანი",
+    "Show screen" : "ეკრანის ჩვენება",
+    "Disable video" : "ვიდეოს გათიშვა",
+    "Enable video" : "ვიდეოს ამოქმედება",
+    "Favorite" : "რჩეული",
+    "Remove from favorites" : "რჩეულებიდან ამოშლა",
+    "Add to favorites" : "რჩეულებში დამატება",
+    "Contacts" : "კონტაქტები",
+    "Groups" : "ჯგუფები",
+    "Circles" : "წრეები",
+    "Loading" : "იტვირთება",
+    "Error" : "შეცდომა",
+    "Password protect" : "პაროლით დაცვა",
+    "Back" : "უკან",
+    "Close" : "დახურვა",
+    "Conversation name" : "საუბრის სახელწოდება",
+    "Reply" : "პასუხი",
+    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
+    "Today" : "დღეს",
+    "Yesterday" : "გუშინ",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "moderator" : "მოდერატორი",
+    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
+    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
+    "Remove participant" : "მონაწილის ამოშლა",
+    "No results" : "შედეგები არაა",
+    "Participants" : "მონაწილეები",
+    "Guests" : "სტუმრები",
+    "Share link" : "ბმულის გაზიარება",
+    "Password protection" : "პაროლით თავდაცვა",
+    "Enter a password" : "შეიყვანეთ პაროლი",
+    "Chat" : "ჩეთი",
+    "Edit" : "შეცვლა",
+    "Leave call" : "ზარის დატოვება",
+    "Limit to groups" : "ლიმიტი ჯგუფებზე",
+    "Save changes" : "ცვილებების შენახვა",
+    "Saved!" : "შენახულია!",
+    "Name" : "სახელი",
+    "General settings" : "მთავარი პარამეტრები",
     "Saved" : "დამახსოვრდა",
     "Shared secret" : "გაზიარებული საიდუმლო",
     "STUN servers" : "STUN სერვერები",
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
+    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
+    "Password required" : "საჭიროა პაროლი",
+    "Password" : "პაროლი",
+    "Cancel" : "უარყოფა",
+    "Submit" : "გაგზავნა",
+    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
+    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
+    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
+    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
+    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
     "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
     "TURN server" : "TURN სერვერი",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
+    "Android app" : "Android აპლიკაცია",
+    "iOS app" : "iOS აპლიკაცია",
     "Delete server" : "სერვერის გაუქმება",
     "Add new server" : "ახალი სერვერის დამატება",
     "TURN server shared secret" : "TURN სერვერმა გააზიარა საიდუმლო",
+    "Copy" : "კოპირება",
+    "Copied!" : "კოპირებულია!",
+    "Not supported!" : "არ არის მხარდაჭერილი!",
+    "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
+    "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
+    "Share" : "გაზიარება",
+    "Change password" : "პაროლის შეცვლა",
+    "Set password" : "პაროლის დაყენება",
+    "Rename" : "სახელის შეცვლა",
+    "Conversation with {name}" : "საუბარი მომხმარებელთან {name}",
+    "Error occurred while setting password" : "პაროლის დაყენებისას წარმოიქმნა შეცდომა",
+    "Link copied!" : "ბმული დაკოპირდა!",
+    "You" : "თქვენ",
+    "No messages yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
+    "Send" : "გაგზავნა",
+    "Error occurred while sending message" : "წერილის გაგზავნისას წარმოიშვა შეცდომა",
+    "Error while sharing" : "შეცდომა გაზიარების დროს",
+    "Waiting for {participantName} to join the call …" : "ზარში შემოსვლისთვის ველოდებით მომხმარებელს {participantName} …",
+    "WebRTC is not supported in your browser :-/" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს :-/",
+    "Waiting for camera and microphone permissions" : "ველოდებით კამერის და მიკროფონის უფლებებს",
+    "Please, give your browser access to use your camera and microphone in order to use this app." : "ამ აპლიკაციის გამოყენბისთვის გთხოვთ მიანიჭოთ ბრაუზერს წვდომა კამერასა და მიკროფონზე.",
+    "Mute audio" : "ხმის ჩახშობა",
+    "Share screen" : "ეკრანის გაზიარება",
+    "No Camera" : "კამერა არაა",
+    "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
+    "Favorited" : "დამატებულია რჩეულებში",
+    "{participantName}'s screen" : "{participantName} მომხმარებლის ეკრანი",
+    "Guest's screen" : "სტუმრის ეკრანი",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "თქვენ დაგპატიჟეს ოთახში <strong>სასაუბროთ</strong> ან მიიღეთ <strong>ზარი</strong>",
     "_%n other guest_::_%n other guests_" : ["%n სხვა სტუმარი","%n სხვა სტუმარი"],
     ", " : ",",
