@@ -16,32 +16,102 @@ OC.L10N.register(
     "Join call" : "Ta del i samtale",
     "{user} wants to talk with you" : "{user} ønsker å snakke med deg",
     "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
+    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
+    "None" : "Ingen",
+    "User" : "Bruker",
+    "Everyone" : "Alle",
+    "Disabled" : "Deaktivert",
+    "Users" : "Brukere",
     "Validate SSL certificate" : "Bekreft SSL-sertifikat",
     "STUN server URL" : "STUN server URL",
     "TURN server protocols" : "TURN-serverprotokoller",
     "UDP and TCP" : "UDP og TCP",
     "UDP only" : "kun UDP",
     "TCP only" : "kun TCP",
-    "[Unknown user name]" : "[Ukjent brukernavn]",
     "Copy link" : "Kopier lenke",
+    "No other people in this call" : "Ingen andre personer i denne samtalen",
+    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
+    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
+    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
+    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
+    "Show your screen" : "Vis din skjerm",
+    "Stop screensharing" : "Stopp skjermdeling",
+    "No audio" : "Ingen lyd",
+    "Mute audio (m)" : "Slå av lyd (m)",
+    "Unmute audio (m)" : "Slå på lyd (m)",
+    "Disable video (v)" : "Skru av video (v)",
+    "Enable video (v)" : "Skru på video (v)",
+    "Screensharing options" : "Skjermdelingsvalg",
+    "Enable screensharing" : "Skru på skjermdeling",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
+    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
+    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
+    "Your screen" : "Din skjerm",
+    "Show screen" : "Vis skjerm",
+    "Disable video" : "Skru av video",
+    "Enable video" : "Skru på video",
+    "Favorite" : "Merk som favoritt",
     "Leave conversation" : "Forlat samtale",
     "Delete conversation" : "Slett samtale",
+    "Remove from favorites" : "Fjern fra favoritter",
     "Add to favorites" : "Legg til i favoritter",
+    "Conversations" : "Samtaler",
+    "Contacts" : "Kontakter",
+    "Groups" : "Grupper",
+    "Circles" : "Sirkler",
+    "Loading" : "Laster",
+    "Error" : "Feil",
+    "Password protect" : "Passordbeskyttelse",
+    "Back" : "Tilbake",
+    "Close" : "Lukk",
+    "Conversation name" : "Samtalenavn",
+    "Reply" : "Svar",
+    "[Unknown user name]" : "[Ukjent brukernavn]",
+    "Today" : "I dag",
+    "Yesterday" : "I går",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "moderator" : "moderator",
+    "guest" : "gjest",
     "Demote from moderator" : "Fjern moderatorstatus",
     "Promote to moderator" : "Gi moderatorstatus",
     "Remove participant" : "Fjern deltaker",
-    "Share link" : "Del lenke",
+    "No results" : "Ingen resultater",
     "Participants" : "Deltakere",
+    "Rename conversation" : "Endre navn på samtale",
+    "Guests" : "Gjester",
+    "Share link" : "Del lenke",
+    "Password protection" : "Passordbeskyttelse",
+    "Enter a password" : "Skriv inn et passord",
+    "Chat" : "Sludre",
+    "Projects" : "Prosjekter",
+    "Edit" : "Rediger",
+    "Leave call" : "Forlat samtalen",
+    "Start call" : "Start samtale",
+    "Limit to groups" : "Begrens til grupper",
+    "Save changes" : "Lagre endringer",
+    "Saving …" : "Lagrer...",
+    "Saved!" : "Lagret!",
     "Name" : "Navn",
+    "General settings" : "Generelle innstillinger",
     "Saved" : "Lagret",
     "Shared secret" : "Delt hemmelighet",
     "STUN servers" : "STUN-server",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
     "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
-    "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
+    "Please enter the password for this call" : "Skriv inn passordet for denne samtalen",
+    "Password required" : "Passord kreves",
     "Password" : "Passord",
-    "Fullscreen (f)" : "Fullskjermsvisning (f)",
+    "Cancel" : "Avbryt",
+    "Submit" : "Send inn",
+    "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
+    "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
+    "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
+    "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
+    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
+    "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
+    "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signalserver kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signalserver.",
     "TURN server" : "TURN-server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-serveren fungerer som mellomserver for trafikk fra deltakere bak en brannmur.",
@@ -52,25 +122,21 @@ OC.L10N.register(
     "Add new server" : "Legg til ny server",
     "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du slettet alle STUN-servere. Siden behovet nesten alltid er der, har en forvalgt STUN-server blitt lagt til.",
     "TURN server shared secret" : "TURN-servers delte hemmelighet",
+    "Test server" : "Test-server",
     "New public conversation" : "Ny offentlig samtale",
     "New group conversation" : "Ny gruppesamtale",
     "New conversation …" : "Ny samtale…",
-    "Chat" : "Sludre",
     "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
+    "Fullscreen (f)" : "Fullskjermsvisning (f)",
     "Copy" : "Kopier",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Ikke støttet!",
     "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
     "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
-    "Please enter the password for this call" : "Skriv inn passordet for denne samtalen",
-    "Password required" : "Passord kreves",
-    "Cancel" : "Avbryt",
-    "Submit" : "Send inn",
-    "Leave call" : "Forlat samtalen",
-    "Start call" : "Start samtale",
+    "Start a conversation" : "Start en samtale",
+    "Share" : "Del",
     "Change password" : "Endre passord",
     "Set password" : "Velg passord",
-    "Conversation name" : "Samtalenavn",
     "Rename" : "Gi nytt navn",
     "Conversation with {name}" : "Samtale med {name}",
     "Error occurred while setting password" : "Feil oppstod ved setting av passord",
@@ -79,50 +145,22 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Ingen meldinger enda, start samtalen!",
     "New message …" : "Ny melding …",
     "Send" : "Send",
-    "Today" : "I dag",
-    "Yesterday" : "I går",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "Feil oppstod under foresendelse av melding",
-    "Edit" : "Rediger",
-    "No other people in this call" : "Ingen andre personer i denne samtalen",
+    "Error while sharing" : "En feil har oppstått under deling",
     "Waiting for {participantName} to join the call …" : "Venter på at {participantName} skal bli med i samtalen…",
-    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
-    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
-    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
-    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
     "WebRTC is not supported in your browser :-/" : "WebRTC støttes ikke av din nettleser :-/",
-    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
     "Waiting for camera and microphone permissions" : "Venter på kamera- og mikrofon-tilganger",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Gi nettleseren tilgang til å bruke kamera og mikrofon for å kunne bruke denne appen.",
-    "Disable video" : "Skru av video",
+    "Mute audio" : "Slå av lyd",
     "Share screen" : "Del skjerm",
-    "Show your screen" : "Vis din skjerm",
-    "Stop screensharing" : "Stopp skjermdeling",
-    "Unmute audio (m)" : "Slå på lyd (m)",
-    "Mute audio (m)" : "Slå av lyd (m)",
-    "No audio" : "Ingen lyd",
-    "Enable video (v)" : "Skru på video (v)",
-    "Disable video (v)" : "Skru av video (v)",
     "No Camera" : "Inget kamera",
     "Screensharing is not supported by your browser." : "Skjermdeling støttes ikke av din nettleser.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
-    "Screensharing options" : "Skjermdelingsvalg",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
-    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
-    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
-    "Enable screensharing" : "Skru på skjermdeling",
     "Add participant …" : "Legg til deltager…",
-    "Close" : "Lukk",
-    "Show screen" : "Vis skjerm",
-    "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
-    "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
-    "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
-    "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
-    "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
+    "Favorited" : "Favorisert",
+    "Always notify" : "Alltid varsle",
+    "Never notify" : "Aldri varsle",
     "{participantName}'s screen" : "{participantName}'s skjerm",
     "Guest's screen" : "Gjestens skjerm",
-    "Your screen" : "Din skjerm",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du ble invitert til et <strong>samtale</strong>-rom, eller fikk et <strong>anrop</strong>",
     "_%n other guest_::_%n other guests_" : ["%n annen gjest","%n andre gjester"],
     ", " : ", ",
