@@ -14,37 +14,98 @@ OC.L10N.register(
     "Join call" : "Juntar-se à chamada",
     "{user} wants to talk with you" : "{utilizador} quer falar consigo",
     "A group call has started in {call}" : "Uma chamada de grupo começou em {chamada}",
+    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
+    "None" : "Nenhum",
+    "User" : "Utilizador",
+    "Everyone" : "Para todos",
+    "Disabled" : "Desactivado",
+    "Users" : "Utilizadores",
     "Validate SSL certificate" : "Validar certificado SSL",
     "TURN server protocols" : "Protocolos do servidor TURN",
     "UDP and TCP" : "UDP e TCP",
     "UDP only" : "Só UDP",
     "TCP only" : "Só TCP",
-    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
     "Copy link" : "Copiar ligação",
+    "No other people in this call" : "Sem mais pessoas nesta chamada",
+    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
+    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
+    "Share this link to invite others!" : "Envie este link para convidar outros!",
+    "Screensharing options" : "Opções de partilha de ecrã",
+    "Enable screensharing" : "Activar partilha de ecrã",
+    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
+    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
+    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
+    "Your screen" : "O seu ecrã",
+    "Show screen" : "Mostrar ecrã",
+    "Disable video" : "desactivar vídeo",
+    "Enable video" : "activar vídeo",
+    "Favorite" : "Favorito",
+    "Leave conversation" : "Sair da conversação",
+    "Delete conversation" : "Eliminar conversação",
+    "Remove from favorites" : "Remover de favoritos",
+    "Add to favorites" : "Adicionar aos favoritos",
+    "Conversations" : "Conversações",
+    "Contacts" : "Contactos",
+    "Groups" : "Grupos",
+    "Circles" : "Círculos",
+    "Loading" : "A carregar",
+    "Error" : "Erro",
+    "Password protect" : "Proteger com palavra-passe",
+    "Back" : "Anterior",
+    "Close" : "Fechar",
+    "Conversation name" : "Nome da conversação",
+    "Reply" : "Resposta",
+    "[Unknown user name]" : "[Nome de utilizador desconhecido]",
+    "Today" : "Hoje",
+    "Yesterday" : "Ontem",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "moderator" : "moderador",
+    "guest" : "convidado",
     "Demote from moderator" : "Relegar de moderador",
     "Promote to moderator" : "Promover a moderador",
     "Remove participant" : "Remover participante",
-    "Share link" : "Partilhar ligação",
+    "No results" : "Sem resultados",
     "Participants" : "Participantes",
+    "Rename conversation" : "Renomear conversação",
+    "Guests" : "Convidados",
+    "Share link" : "Partilhar ligação",
+    "Password protection" : "Protegido por palavra-passe",
+    "Enter a password" : "Insira uma palavra-passe",
+    "Chat" : "Conversa",
+    "Edit" : "Editar",
+    "Leave call" : "Sair da chamada",
+    "Limit to groups" : "Limitado a grupos",
+    "Limit app usage to groups." : "Limitar o uso da aplicação a grupos.",
+    "Save changes" : "Guardar alterações",
+    "Saved!" : "Gravado!",
     "Name" : "Nome",
     "Saved" : "Gravado",
     "Shared secret" : "Segredo partilhado",
+    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
+    "Password required" : "Necessário palavra-passe",
     "Password" : "Palavra-passe",
+    "Cancel" : "Cancelar",
+    "Submit" : "Submeter",
+    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
+    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
+    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
+    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
+    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
+    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
+    "Android app" : "Aplicação Android",
+    "iOS app" : "Aplicação iOS",
     "Delete server" : "Apagar servidor",
     "Add new server" : "Adicionar novo servidor",
-    "Chat" : "Conversa",
+    "New public conversation" : "Nova conversação pública",
     "Copy" : "Copiar",
     "Copied!" : "Copiado!",
     "Not supported!" : "Não suportado!",
     "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
+    "Start a conversation" : "Iniciar uma conversação",
     "Share" : "Partilhar",
-    "Please enter the password for this call" : "Por favor introduza a palavra-passe para esta chamada",
-    "Password required" : "Necessário palavra-passe",
-    "Cancel" : "Cancelar",
-    "Submit" : "Submeter",
-    "Leave call" : "Sair da chamada",
     "Change password" : "Alterar palavra-passe",
     "Set password" : "Definir palavra-passe",
     "Rename" : "Renomear",
@@ -55,39 +116,20 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Ainda não tem mensagens, comece a conversa!",
     "New message …" : "Nova mensagem...",
     "Send" : "Enviar",
-    "Today" : "Hoje",
-    "Yesterday" : "Ontem",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Error occurred while sending message" : "Ocorreu um erro a enviar a mensagem",
-    "Edit" : "Editar",
-    "No other people in this call" : "Sem mais pessoas nesta chamada",
+    "Error while sharing" : "Erro ao partilhar",
     "Waiting for {participantName} to join the call …" : "À espera que {nomeDoParticipante} se junte à chamada ..",
-    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
-    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
-    "Share this link to invite others!" : "Envie este link para convidar outros!",
     "WebRTC is not supported in your browser :-/" : "WebRTC não é suportado pelo seu browser :-/",
-    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
     "Waiting for camera and microphone permissions" : "À espera de permissões de câmera e microfone",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Por favor, permite ao seu browser aceder à sua câmera e microfone para que possa utilizar esta aplicação.",
-    "Disable video" : "desactivar vídeo",
+    "Mute audio" : "Silenciar áudio",
     "No Camera" : "Sem Câmera",
     "Screensharing is not supported by your browser." : "O seu browser não suporta partilha de ecrã",
-    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
-    "Screensharing options" : "Opções de partilha de ecrã",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
-    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
-    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
-    "Enable screensharing" : "Activar partilha de ecrã",
-    "Close" : "Fechar",
-    "Show screen" : "Mostrar ecrã",
-    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
-    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
-    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
-    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
+    "Favorited" : "Nos Favoritos",
+    "Always notify" : "Notificar sempre",
+    "Never notify" : "Nunca notificar",
     "{participantName}'s screen" : "Ecrã de {nomeDeParticipante}",
     "Guest's screen" : "Ecrã do convidado",
-    "Your screen" : "O seu ecrã",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Foi convidado para uma sala de <strong>conversa</strong> ou recebeu uma <strong>chamada</strong>",
     ", " : ","
 },
