@@ -436,10 +436,7 @@ class SignalingController extends OCSController {
 			'room' => [
 				'version' => '1.0',
 				'roomid' => $room->getToken(),
-				'properties' => [
-					'name' => $room->getDisplayName((string) $userId),
-					'type' => $room->getType(),
-				],
+				'properties' => $room->getPropertiesForSignaling((string) $userId),
 			],
 		];
 		if ($event->getSession()) {
@@ -461,15 +458,17 @@ class SignalingController extends OCSController {
 			]);
 		}
 
+		$pingSessionIds = [];
 		$now = $this->timeFactory->getTime();
 		foreach ($request['entries'] as $entry) {
-			if (array_key_exists('userid', $entry)) {
-				$room->ping($entry['userid'], $entry['sessionid'], $now);
-			} else {
-				$room->ping('', $entry['sessionid'], $now);
+			if ($entry['sessionid'] !== '0') {
+				$pingSessionIds[] = $entry['sessionid'];
 			}
 		}
 
+		// Ping all active sessions with one query
+		$room->pingSessionIds($pingSessionIds, $now);
+
 		$response = [
 			'type' => 'room',
 			'room' => [
