@@ -20,18 +20,18 @@ declare(strict_types=1);
  *
  */
 
-namespace OCA\Spreed\Notification;
+namespace OCA\Talk\Notification;
 
 
-use OCA\Spreed\Chat\CommentsManager;
-use OCA\Spreed\Chat\MessageParser;
-use OCA\Spreed\Config;
-use OCA\Spreed\Exceptions\ParticipantNotFoundException;
-use OCA\Spreed\Exceptions\RoomNotFoundException;
-use OCA\Spreed\GuestManager;
-use OCA\Spreed\Manager;
-use OCA\Spreed\Participant;
-use OCA\Spreed\Room;
+use OCA\Talk\Chat\CommentsManager;
+use OCA\Talk\Chat\MessageParser;
+use OCA\Talk\Config;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Exceptions\RoomNotFoundException;
+use OCA\Talk\GuestManager;
+use OCA\Talk\Manager;
+use OCA\Talk\Participant;
+use OCA\Talk\Room;
 use OCP\Comments\NotFoundException;
 use OCP\IL10N;
 use OCP\IURLGenerator;
@@ -44,9 +44,9 @@ use OCP\Notification\IManager as INotificationManager;
 use OCP\Notification\INotification;
 use OCP\Notification\INotifier;
 use OCP\RichObjectStrings\Definitions;
-use OCP\Share;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager as IShareManager;
+use OCP\Share\IShare;
 
 class Notifier implements INotifier {
 
@@ -544,12 +544,12 @@ class Notifier implements INotifier {
 			$notification = $this->addActionButton($notification, $l->t('Call back'));
 		}
 
-		if ($share->getShareType() === Share::SHARE_TYPE_EMAIL) {
+		if ($share->getShareType() === IShare::TYPE_EMAIL) {
 			$sharedWith = $share->getSharedWith();
 			if ($callIsActive) {
 				$subject = $l->t('{email} is requesting the password to access {file}');
 			} else {
-				$subject = $l->t('{email} tried to requested the password to access {file}');
+				$subject = $l->t('{email} tried to request the password to access {file}');
 			}
 
 			$notification
@@ -567,7 +567,7 @@ class Notifier implements INotifier {
 			if ($callIsActive) {
 				$subject = $l->t('Someone is requesting the password to access {file}');
 			} else {
-				$subject = $l->t('Someone tried to requested the password to access {file}');
+				$subject = $l->t('Someone tried to request the password to access {file}');
 			}
 
 			$notification
