@@ -36,6 +36,7 @@ use OCA\Talk\Events\ParticipantEvent;
 use OCA\Talk\Events\RemoveParticipantEvent;
 use OCA\Talk\Events\RemoveUserEvent;
 use OCA\Talk\Events\RoomEvent;
+use OCA\Talk\Events\SignalingRoomPropertiesEvent;
 use OCA\Talk\Events\VerifyRoomPasswordEvent;
 use OCA\Talk\Exceptions\InvalidPasswordException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
@@ -100,6 +101,7 @@ class Room {
 	public const EVENT_AFTER_SESSION_JOIN_CALL = self::class . '::postSessionJoinCall';
 	public const EVENT_BEFORE_SESSION_LEAVE_CALL = self::class . '::preSessionLeaveCall';
 	public const EVENT_AFTER_SESSION_LEAVE_CALL = self::class . '::postSessionLeaveCall';
+	public const EVENT_BEFORE_SIGNALING_PROPERTIES = self::class . '::beforeSignalingProperties';
 
 	/** @var Manager */
 	private $manager;
@@ -278,6 +280,27 @@ class Room {
 		$this->participant = $participant;
 	}
 
+	/**
+	 * Return the room properties to send to the signaling server.
+	 *
+	 * @param string $userId
+	 * @return array
+	 */
+	public function getPropertiesForSignaling(string $userId): array {
+		$properties = [
+			'name' => $this->getDisplayName($userId),
+			'type' => $this->getType(),
+			'lobby-state' => $this->getLobbyState(),
+			'lobby-timer' => $this->getLobbyTimer(),
+			'read-only' => $this->getReadOnly(),
+			'active-since' => $this->getActiveSince(),
+		];
+
+		$event = new SignalingRoomPropertiesEvent($this, $userId, $properties);
+		$this->dispatcher->dispatch(self::EVENT_BEFORE_SIGNALING_PROPERTIES, $event);
+		return $event->getProperties();
+	}
+
 	/**
 	 * @param string|null $userId
 	 * @return Participant
@@ -597,6 +620,17 @@ class Room {
 
 		$this->dispatcher->dispatch(self::EVENT_AFTER_LOBBY_STATE_SET, $event);
 
+		if ($newState === Webinary::LOBBY_NON_MODERATORS) {
+			$participants = $this->getParticipantsInCall();
+			foreach ($participants as $participant) {
+				if ($participant->hasModeratorPermissions()) {
+					continue;
+				}
+
+				$this->changeInCall($participant, Participant::FLAG_DISCONNECTED);
+			}
+		}
+
 		return true;
 	}
 
@@ -668,6 +702,11 @@ class Room {
 			->set('participant_type', $query->createNamedParameter($participantType, IQueryBuilder::PARAM_INT))
 			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->eq('user_id', $query->createNamedParameter($participant->getUser())));
+
+		if ($participant->getUser() === '') {
+			$query->andWhere($query->expr()->eq('session_id', $query->createNamedParameter($participant->getSessionId())));
+		}
+
 		$query->execute();
 
 		$this->dispatcher->dispatch(self::EVENT_AFTER_PARTICIPANT_TYPE_SET, $event);
@@ -956,6 +995,27 @@ class Room {
 		return $participants;
 	}
 
+	/**
+	 * @return Participant[]
+	 */
+	public function getParticipantsInCall(): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('*')
+			->from('talk_participants')
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->neq('in_call', $query->createNamedParameter(Participant::FLAG_DISCONNECTED)));
+
+		$result = $query->execute();
+
+		$participants = [];
+		while ($row = $result->fetch()) {
+			$participants[] = $this->manager->createParticipantObject($this, $row);
+		}
+		$result->closeCursor();
+
+		return $participants;
+	}
+
 	/**
 	 * @param int $lastPing When the last ping is older than the given timestamp, the user is ignored
 	 * @return array[] Array of users with [users => [userId => [lastPing, sessionId]], guests => [[lastPing, sessionId]]]
@@ -1180,4 +1240,18 @@ class Room {
 
 		$query->execute();
 	}
+
+	/**
+	 * @param string[] $sessionIds
+	 * @param int $timestamp
+	 */
+	public function pingSessionIds(array $sessionIds, int $timestamp): void {
+		$query = $this->db->getQueryBuilder();
+		$query->update('talk_participants')
+			->set('last_ping', $query->createNamedParameter($timestamp, IQueryBuilder::PARAM_INT))
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->in('session_id', $query->createNamedParameter($sessionIds), IQueryBuilder::PARAM_STR_ARRAY));
+
+		$query->execute();
+	}
 }
